==> 0.13.zip: unipatcher/app/src/main/res/raw/changelog.md <==
#### 0.13 (January 24, 2017)

- Support IPS32 patches
- Deleted ads. Thanks to all who supported the development of the program.

#### 0.12 (January 13, 2017)

- Support APS patches (Nintendo 64 and Game Boy Advance)
- Added the ability to specify the output directory

#### 0.11 (December 25, 2016)

- Support EBP patches (for EarthBound game)
- Italian translation (Thanks to Matteo Sechi)

#### 0.10.1 (December 6, 2016)

- Added dark theme

#### 0.10 (September 26, 2016)

- Support XDelta3 patches

#### 0.9.2 (September 18, 2016)

- Long tap on the ROM file in file manager to see its checksum (CRC32, SHA1 and MD5).
- Fixed bug

#### 0.9.1 (September 2, 2016)

- The app remembers the last used directory
- Added the ability to configure the directories for patches and ROMs
- Polish translation (Thanks to Michal Bychowski)

#### 0.9 (June 1, 2016)

- Support BPS patches
- Added help page (frequently asked questions)
- Russian translation
- Various improvements and bug fixes

#### 0.8.2 (May 6, 2016)

- Fixed an important bug introduced in version 0.8.1

#### 0.8.1 (April 30, 2016)

- Improved performance. Now patches are applied quickly

#### 0.8 (April 12, 2016)

- Support Marshmallow permissions
- Added ability to rename output file
- Added floating action button
- New colors, icons and navigation bar
- Now the application only runs on devices with Android 4 and above

#### 0.7.3 (January 12, 2015)

- Support Android 5
- Improved design and usability

#### 0.7.2 (May 31, 2014)

- Fixed a bug when the device goes into sleep mode

#### 0.7.1 (May 13, 2014)

- Fixed crash on Android 2.3

#### 0.7 (May 07, 2014)

- By popular demand UniPatcher is now free, but with advertising. It is not displayed if you purchased the program
- Support DPS patches
- Added feature: Fix checksum for Sega Mega Drive ROMs
- Added feature: Add/Delete SMC header for Super Nintendo ROMs

#### 0.6 (November 04, 2013)

- Support PPF patches in full version
- Small improvements

#### 0.5 (October 15, 2013)

- UniPatcher now divided into a lite and full version. You can purchase the full version directly inside the app
- Support UPS patches in full version
- The association with IPS and UPS files. Now you can open the patches from your file manager
- Again redesigned
- Added a dialog "What's New"
- Added icons of high resolution
- Dropped support for Android 2.1. Sorry guys, this is no longer possible to maintain

#### 0.4 (August 24, 2013)

- The result is stored in the new output file

#### 0.3 (May 23, 2013)

- New look and feel
- New icon
- Added a dialog "Rate this App"
- Added a menu "Share"
- Minor changes

#### 0.2 (April 17, 2013)

- Added support for android 2.1
- Added ActionBar for android 2.1+
- Added the ability to install it on sd-card
- Patching in a separate thread, the UI does not freeze
- Added pictures in the file manager
- Bugfixes

#### 0.1 (April 6, 2013)

- Initial release, supports only IPS patches

==> v0.14.2.zip: unipatcher/app/src/main/res/raw/changelog.md <==
#### 0.14.2 (Jule 13, 2017)
- Korean translation (Thanks to Minseo Lee)

#### 0.14.1 (April 30, 2017)
- Norwegian Bokmål translation (Thanks to Allan Nordhøy)
- Japanese translation (Thanks to Naofumi Fukue)
- French translation (Thanks to Thibaut Panis)

#### 0.14 (March 23, 2017)

- Support creating XDelta3 patches
- Added option "ignore checksum"
- Spanish translation (Thanks to Carlos Sánchez)
- Removed analytics library and crash reports

#### 0.13.2 (February 12, 2017)

- Ukrainian translation (Thanks to Volodymyr Shevchuk)

#### 0.13.1 (January 25, 2017)

- Removed rate app dialog

#### 0.13 (January 24, 2017)

- Support IPS32 patches
- Deleted ads. Thanks to all who supported the development of the program.

#### 0.12 (January 13, 2017)

- Support APS patches (Nintendo 64 and Game Boy Advance)
- Added the ability to specify the output directory

#### 0.11 (December 25, 2016)

- Support EBP patches (for EarthBound game)
- Italian translation (Thanks to Matteo Sechi)

#### 0.10.1 (December 6, 2016)

- Added dark theme

#### 0.10 (September 26, 2016)

- Support XDelta3 patches

#### 0.9.2 (September 18, 2016)

- Long tap on the ROM file in file manager to see its checksum (CRC32, SHA1 and MD5).
- Fixed bug

#### 0.9.1 (September 2, 2016)

- The app remembers the last used directory
- Added the ability to configure the directories for patches and ROMs
- Polish translation (Thanks to Michal Bychowski)

#### 0.9 (June 1, 2016)

- Support BPS patches
- Added help page (frequently asked questions)
- Russian translation
- Various improvements and bug fixes

#### 0.8.2 (May 6, 2016)

- Fixed an important bug introduced in version 0.8.1

#### 0.8.1 (April 30, 2016)

- Improved performance. Now patches are applied quickly

#### 0.8 (April 12, 2016)

- Support Marshmallow permissions
- Added ability to rename output file
- Added floating action button
- New colors, icons and navigation bar
- Now the application only runs on devices with Android 4 and above

#### 0.7.3 (January 12, 2015)

- Support Android 5
- Improved design and usability

#### 0.7.2 (May 31, 2014)

- Fixed a bug when the device goes into sleep mode

#### 0.7.1 (May 13, 2014)

- Fixed crash on Android 2.3

#### 0.7 (May 7, 2014)

- By popular demand UniPatcher is now free, but with advertising. It is not displayed if you purchased the program
- Support DPS patches
- Added feature: Fix checksum for Sega Mega Drive ROMs
- Added feature: Add/Delete SMC header for Super Nintendo ROMs

#### 0.6 (November 4, 2013)

- Support PPF patches in full version
- Small improvements

#### 0.5 (October 15, 2013)

- UniPatcher now divided into a lite and full version. You can purchase the full version directly inside the app
- Support UPS patches in full version
- The association with IPS and UPS files. Now you can open the patches from your file manager
- Again redesigned
- Added a dialog "What's New"
- Added high resolution icons
- Dropped support for Android 2.1. Sorry guys, this is no longer possible to maintain

#### 0.4 (August 24, 2013)

- The result is stored in the new output file

#### 0.3 (May 23, 2013)

- New look and feel
- New icon
- Added a dialog "Rate this App"
- Added a menu "Share"
- Minor changes

#### 0.2 (April 17, 2013)

- Added support for Android 2.1
- Added ActionBar for Android 2.1+
- Added the ability to install it on SD-card
- Patching in a separate thread, the UI does not freeze
- Added pictures in the file manager
- Bugfixes

#### 0.1 (April 6, 2013)

- Initial release, supports only IPS patches
